@@ -2,11 +2,12 @@ package WebService::PayPal::PaymentsAdvanced;
 
 use Moo;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000016';
 
 use feature qw( say state );
 
 use Data::GUID;
+use List::AllUtils qw( any );
 use LWP::UserAgent;
 use MooX::StrictConstructor;
 use Type::Params qw( compile );
@@ -38,6 +39,7 @@ use WebService::PayPal::PaymentsAdvanced::Response::Sale;
 use WebService::PayPal::PaymentsAdvanced::Response::Sale::CreditCard;
 use WebService::PayPal::PaymentsAdvanced::Response::Sale::PayPal;
 use WebService::PayPal::PaymentsAdvanced::Response::SecureToken;
+use WebService::PayPal::PaymentsAdvanced::Response::Void;
 #>>>
 
 has nonfatal_result_codes => (
@@ -262,6 +264,7 @@ sub post {
         D => 'Response::Capture',
         I => 'Response::Inquiry',
         S => 'Response::Sale',
+        V => 'Response::Void',
     );
 
     my $type                  = $post->{TRXTYPE};
@@ -271,7 +274,7 @@ sub post {
         $response_class_suffix = $class_for_type{$type};
 
         # Get more specific response classes for CC and PayPal txns.
-        unless ( $type eq 'D' ) {
+        unless ( any { $type eq $_ } ( 'D', 'V' ) ) {
             my $response = $self->_response_for(
                 $response_class_suffix,
                 params => $params
@@ -421,7 +424,7 @@ WebService::PayPal::PaymentsAdvanced - A simple wrapper around the PayPal Paymen
 
 =head1 VERSION
 
-version 0.000015
+version 0.000016
 
 =head1 SYNOPSIS
 
@@ -745,6 +748,11 @@ the ID of the original transaction.  Returns a response object.
 Voids a previous transaction.  Requires the ID of the transaction to void.
 Returns a response object.
 
+=head1 SEE ALSO
+
+The official L<Payflow Gateway Developer Guide and
+Reference|https://developer.paypal.com/docs/classic/payflow/integration-guide/>
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
@@ -771,7 +779,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
