@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro;
 
 use Mojolicious::Lite;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000016';
 
 use feature qw( state );
 
@@ -33,7 +33,7 @@ post '/' => sub {
     }
 
     if ( !$params->{TRXTYPE}
-        || none { $params->{TRXTYPE} eq $_ } ( 'A', 'D', 'I', 'S' ) ) {
+        || none { $params->{TRXTYPE} eq $_ } ( 'A', 'D', 'I', 'S', 'V', ) ) {
         $c->render( text => 'Mocked URL not found', status => 404 );
         return;
     }
@@ -170,6 +170,20 @@ post '/' => sub {
         }
     }
 
+    if ( $params->{TRXTYPE} eq 'V' ) {
+        my %return = (
+            CORRELATIONID => $helper->correlationid,
+            PENDINGREASON => 'authorization',
+            PNREF         => $helper->pnref,
+            PPREF         => $helper->ppref,
+            RESPMSG       => 'Approved',
+            RESULT        => 0,
+            TRANSTIME     => $helper->transtime,
+        );
+        _render_response( $c, \%return );
+        return;
+    }
+
     $c->render( text => 'Mocked URL not found', status => 404 );
 };
 
@@ -221,7 +235,7 @@ WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro - A simple app to enabl
 
 =head1 VERSION
 
-version 0.000015
+version 0.000016
 
 =head1 DESCRIPTION
 
@@ -246,7 +260,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
