@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Response::Authorization;
 
 use Moo;
 
-our $VERSION = '0.000015';
+our $VERSION = '0.000016';
 
 extends 'WebService::PayPal::PaymentsAdvanced::Response';
 
@@ -19,11 +19,11 @@ WebService::PayPal::PaymentsAdvanced::Response::Authorization - Response class f
 
 =head1 VERSION
 
-version 0.000015
+version 0.000016
 
 =head1 DESCRIPTION
 
-Response class for Sale transactions C<TRXTYPE=S>  You should not create this
+Response class for Authorization transactions C<TRXTYPE=A>  You should not create this
 response object directly. This module inherits from
 L<WebService::PayPal::PaymentsAdvanced::Response> and includes the methods
 provided by L<WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTime>
@@ -35,7 +35,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
